@@ -17,10 +17,9 @@
 
 """IPv6 helper functions."""
 
-from typing import List, Union
-
-import re
 import binascii
+import re
+from typing import List
 
 import dns.exception
 import dns.ipv4
@@ -102,10 +101,10 @@ _colon_colon_start = re.compile(rb"::.*")
 _colon_colon_end = re.compile(rb".*::$")
 
 
-def inet_aton(text: Union[str, bytes], ignore_scope: bool = False) -> bytes:
+def inet_aton(text: str | bytes, ignore_scope: bool = False) -> bytes:
     """Convert an IPv6 address in text form to binary form.
 
-    *text*, a ``str``, the IPv6 address in textual form.
+    *text*, a ``str`` or ``bytes``, the IPv6 address in textual form.
 
     *ignore_scope*, a ``bool``.  If ``True``, a scope will be ignored.
     If ``False``, the default, it is an error for a scope to be present.
@@ -144,9 +143,7 @@ def inet_aton(text: Union[str, bytes], ignore_scope: bool = False) -> bytes:
     if m is not None:
         b = dns.ipv4.inet_aton(m.group(2))
         btext = (
-            "{}:{:02x}{:02x}:{:02x}{:02x}".format(
-                m.group(1).decode(), b[0], b[1], b[2], b[3]
-            )
+            f"{m.group(1).decode()}:{b[0]:02x}{b[1]:02x}:{b[2]:02x}{b[3]:02x}"
         ).encode()
     #
     # Try to turn '::<whatever>' into ':<whatever>'; if no match try to
@@ -207,3 +204,14 @@ def is_mapped(address: bytes) -> bool:
     """
 
     return address.startswith(_mapped_prefix)
+
+
+def canonicalize(text: str | bytes) -> str:
+    """Verify that *address* is a valid text form IPv6 address and return its
+    canonical text form.  Addresses with scopes are rejected.
+
+    *text*, a ``str`` or ``bytes``, the IPv6 address in textual form.
+
+    Raises ``dns.exception.SyntaxError`` if the text is not valid.
+    """
+    return inet_ntoa(inet_aton(text))
