@@ -26,41 +26,37 @@ import dns.tokenizer
 def _validate_float_string(what):
     if len(what) == 0:
         raise dns.exception.FormError
-    if what[0] == b'-'[0] or what[0] == b'+'[0]:
+    if what[0] == b"-"[0] or what[0] == b"+"[0]:
         what = what[1:]
     if what.isdigit():
         return
     try:
-        (left, right) = what.split(b'.')
+        (left, right) = what.split(b".")
     except ValueError:
         raise dns.exception.FormError
-    if left == b'' and right == b'':
+    if left == b"" and right == b"":
         raise dns.exception.FormError
-    if not left == b'' and not left.decode().isdigit():
+    if not left == b"" and not left.decode().isdigit():
         raise dns.exception.FormError
-    if not right == b'' and not right.decode().isdigit():
+    if not right == b"" and not right.decode().isdigit():
         raise dns.exception.FormError
 
 
 @dns.immutable.immutable
 class GPOS(dns.rdata.Rdata):
-
     """GPOS record"""
 
     # see: RFC 1712
 
-    __slots__ = ['latitude', 'longitude', 'altitude']
+    __slots__ = ["latitude", "longitude", "altitude"]
 
     def __init__(self, rdclass, rdtype, latitude, longitude, altitude):
         super().__init__(rdclass, rdtype)
-        if isinstance(latitude, float) or \
-           isinstance(latitude, int):
+        if isinstance(latitude, float) or isinstance(latitude, int):
             latitude = str(latitude)
-        if isinstance(longitude, float) or \
-           isinstance(longitude, int):
+        if isinstance(longitude, float) or isinstance(longitude, int):
             longitude = str(longitude)
-        if isinstance(altitude, float) or \
-           isinstance(altitude, int):
+        if isinstance(altitude, float) or isinstance(altitude, int):
             altitude = str(altitude)
         latitude = self._as_bytes(latitude, True, 255)
         longitude = self._as_bytes(longitude, True, 255)
@@ -73,19 +69,21 @@ class GPOS(dns.rdata.Rdata):
         self.altitude = altitude
         flat = self.float_latitude
         if flat < -90.0 or flat > 90.0:
-            raise dns.exception.FormError('bad latitude')
+            raise dns.exception.FormError("bad latitude")
         flong = self.float_longitude
         if flong < -180.0 or flong > 180.0:
-            raise dns.exception.FormError('bad longitude')
+            raise dns.exception.FormError("bad longitude")
 
     def to_text(self, origin=None, relativize=True, **kw):
-        return '{} {} {}'.format(self.latitude.decode(),
-                                 self.longitude.decode(),
-                                 self.altitude.decode())
+        return (
+            f"{self.latitude.decode()} {self.longitude.decode()} "
+            f"{self.altitude.decode()}"
+        )
 
     @classmethod
-    def from_text(cls, rdclass, rdtype, tok, origin=None, relativize=True,
-                  relativize_to=None):
+    def from_text(
+        cls, rdclass, rdtype, tok, origin=None, relativize=True, relativize_to=None
+    ):
         latitude = tok.get_string()
         longitude = tok.get_string()
         altitude = tok.get_string()
@@ -94,15 +92,15 @@ class GPOS(dns.rdata.Rdata):
     def _to_wire(self, file, compress=None, origin=None, canonicalize=False):
         l = len(self.latitude)
         assert l < 256
-        file.write(struct.pack('!B', l))
+        file.write(struct.pack("!B", l))
         file.write(self.latitude)
         l = len(self.longitude)
         assert l < 256
-        file.write(struct.pack('!B', l))
+        file.write(struct.pack("!B", l))
         file.write(self.longitude)
         l = len(self.altitude)
         assert l < 256
-        file.write(struct.pack('!B', l))
+        file.write(struct.pack("!B", l))
         file.write(self.altitude)
 
     @classmethod
